# SCD Type 2 Package

This is a Python package for handling Slowly Changing Dimension (SCD) Type 2 logic with support for Spark and Pandas DataFrames.

## Installation

You can install the package using `pip`:

```bash
pip install scdhelper
